@@ -1,8 +1,11 @@
 import os, os.path, shutil, logging, sys, filecmp, stat, re, time
+
+
 from puke.FileList import *
 from puke.Console import *
 from scss import Scss
 from puke.FileSystem import *
+from puke.Compress import *
 
 
 CSS_COMPRESSOR = sys.argv[0] + '.css.compress'
@@ -85,7 +88,7 @@ def minify(in_file, out_file = None, verbose=False):
 
 
 def jslint(files, fix = False, strict = False, nojsdoc = False, relax = False):
-    in_files = FileList.check(in_files)
+    files = FileList.check(files)
 
     options = []
     command = ""
@@ -143,16 +146,7 @@ def sh (command, header = None, output = True):
 
 def deepcopy(file_list, folder, replace = None):
 
-    if isinstance(file_list, FileList):
-        file_list = file_list.get(True)
-    elif isinstance(file_list, str):
-        file_list = [(file_list, '')]
-    else:
-        result = []
-        for f in file_list:
-            result.append( ( f, ''))
-        file_list = result
-        del result
+    file_list = FileList.check(file_list, True)
 
     stat = 0
     console.header( "- copy to %s (%s files)" % (folder, len(file_list)))
@@ -193,10 +187,7 @@ def deepcopy(file_list, folder, replace = None):
 
 
 def stats(file_list, title = ""):
-    if isinstance(file_list, FileList):
-        file_list = file_list.get()
-    elif isinstance(file_list, str):
-        file_list = [file_list]
+    file_list = FileList.check(file_list)
 
     size = __exec("du %s | cut  -f1 |(tr '\n' '+'; echo 0) | bc" % ' '.join(file_list))
 
@@ -221,6 +212,50 @@ def stats(file_list, title = ""):
     console.info(  "   ~ Size : %s (%s per file)" % (hsizeof(size), hsizeof((size / len(file_list)))))
     console.info("")
 
+
+
+def pack (file_list, output):
+
+    file_list = FileList.check(file_list)
+
+    console.header( "- Packing files to %s (%s files)" % (output, len(file_list)))
+
+    comp = Compress.open(output, "w")
+     
+    for file in file_list:
+        console.info(' * %s' % __pretty(file))
+        comp.add(file)
+
+    comp.close()
+
+    console.confirm(" %s packed" % output)
+
+def unpack (pack_file, output):
+    
+    console.header( "- Unpacking %s to %s " % (pack_file, output))
+
+    if not Compress.check(pack_file):
+        console.error(" %s is not a valid pack" % output)
+        return
+
+    comp = Compress.open(pack_file, "r")
+    
+    
+
+    count = 0
+    for fname in comp:
+        data = comp.extract(fname)
+        
+        output_file = os.path.join(output, fname)
+        console.info(' + %s' % __pretty(output_file))
+        writefile(output_file, data)
+        count += 1
+    
+    comp.close()
+    console.confirm(" %s unpacked in %s (%s files)" % (pack_file, output, count))
+
+     
+
 def __pretty(filename):
     if filename.startswith('.pukecache'):
         return PukeBuffer.getInfo(filename.split('/').pop())
